# Dipolfeld
# von Dorian Weber

reset
set encoding iso_8859_1
set terminal postscript eps enhanced color 20
set output "../P8_dipole.eps"

# Formeln
# Abstand
dist(x,y)     = sqrt(x*x+y*y)
# Potentiale (symmetrisch)
v1(x,y)    = q1 / dist(x-x0, y)
v2(x,y)    = q2 / dist(x+x0, y)

# Gesamtpotential
vtot(x,y)  = v1(x,y) + v2(x,y)

# Beitrag des E-Felds fr das erste Potential
e1x(x,y)   = q1 * (x-x0)/dist(x-x0,y)**3
e1y(x,y)   = q1 * (y)/dist(x-x0,y)**3
# Beitrag des E-Felds fr das zweite Potential
e2x(x,y)   = q2 * (x+x0)/dist(x+x0,y)**3
e2y(x,y)   = q2 * (y)/dist(x+x0,y)**3

# Gesamtbeitrag
etotx(x,y) = e1x(x,y) + e2x(x,y)
etoty(x,y) = e1y(x,y) + e2y(x,y)

# Normierungsfaktor
enorm(x,y) = dist(etotx(x,y), etoty(x,y))

dx(x,y)   = coef * etotx(x,y)/enorm(x,y)
dy(x,y)   = coef * etoty(x,y)/enorm(x,y)

# Konstanten
density = 0.3
q1 = 1.0*density
x0 = 4.0*density
q2 = -1.0*density
coef = 0.5
xmin = -10.0*density
xmax = 10.0*density
ymin = -10.0*density
ymax = 10.0*density

# quipotentialkurven in Datei plotten
set isosamples 64, 64
unset surface
set contour base
set cntrparam order 4
set cntrparam linear
set cntrparam levels discrete -3*density, -2*density, -1*density, -0.5*density, -0.2*density, -0.1*density, -0.05*density, -0.02*density, 0,\
                              0.02*density, 0.05*density, 0.1*density, 0.2*density, 0.5*density, 1*density, 2*density, 3*density 
set cntrparam points 5
set table "equipo2.tmp"
splot vtot(x,y) with lines
unset table
reset

# Vektorfeld/Feldlinien in Datei plotten
set isosamples 32, 32
set table "field2xy.tmp"
splot vtot(x,y) with lines
unset table
reset

# Stildefinitionen

# quipotentialkurven
set style line 1 lt 1 lw 0.01 lc rgb "dark-blue"
# Vektorfeld
set style line 2 lt 1 lw 0.01 lc rgb "dark-green"

# alles rendern
unset autoscale
set nokey
unset xtics
unset ytics
set xrange [xmin:xmax]
set yrange [ymin:ymax]
set noborder

plot "equipo2.tmp" with lines ls 1,\
     "field2xy.tmp" using 1:2:(dx($1,$2)):(dy($1,$2)) with vectors head filled ls 2
